---
title: "Pedagogy Support using AG2 - Jan 16, 2025"
---

### Speakers: Dr. Benjamin Stern, Peter Nadel

### Biography of the speakers:
Peter Nadel is the Digital Humanities Natural Language Processing Specialist in Research Technology, Tufts Technology Services. In this role, he helps faculty, students and staff to analyze large corpora of documents at scale. He has enabled several faculty to understand their textual data from across many different departments on a variety of grants and projects. His research explores how artificial intelligence and large language models can be used to enable and facilitate classroom learning across several disciplines. He also studies the how these tools work with under-resourced languages, which have been traditionally disregarded by natural language processing.

Dr. Benjamin Stern is an Assistant Professor in the Doctor of Physical Therapy program at Tufts University School of Medicine. His research focuses on two key areas: developing educational technologies to enhance teaching and learning outcomes and predicting injury risk through dynamical systems modeling and machine learning. He has secured funding from the NIH, Tufts University Data Intensive Studies Center, and the Clinical and Translational Research Institute for projects that apply artificial intelligence to cross-disciplinary learning and healthcare outcomes. Dr. Stern maintains an active clinical practice while conducting research. His work appears in publications and presentations spanning evidence-based practice, injury prevention, digital patient simulation, and machine learning applications in healthcare.

### Abstract:
In the evolving landscape of higher education, physical therapy and dental programs face increasing challenges in delivering high-quality assessments and personalized feedback to large student cohorts. At Tufts University, we’re developing an innovative solution using AG2's multi-agent framework to create sophisticated assessment workflows. We’re creating multi-agent workflows to develop multiple choice questions and detailed feedback that maintain educational rigor while scaling efficiently for classes of 70-100 students. This presentation explores how AG2's agent architecture enables automated yet nuanced assessment creation, enhances feedback quality, and supports faculty in maintaining high academic standards. We'll demonstrate how this approach not only streamlines the assessment process but also ensures consistency and personalization across our physical therapy and dental programs.
